#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2006, 2014. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Define the environment variables corresponding to the
# # rm_upgrade.sh script parameters and their default values
# #
# #===========================================================
# #
# # This file is read at the beginning of the rm_upgrade.sh
# # script execution. It sets one environment variable per
# # valid parameter with a predefined default value.
# #
# # Users may want to modify the default value in order to
# # launch the rm_upgrade.sh script with their own values
# # without having to enter the parameter and its
# # corresponding value manually at the command line.
# #
# # WARNING:
# # Not all variables are required to be set for every
# # application.  Read each comment carefully before modifying
# # the value.
# #
# #############################################################

# 매개변수: -oldApplicationHome
# 사용법: -oldApplicationHome <디렉토리 경로>
# 설명:
# 	이전 설치에서 애플리케이션 홈 디렉토리에 대한 전체 경로입니다.
# 기본값:
# 	<없음>
# 제한조건:
#  - 필수 매개변수임
#  - <디렉토리 경로>는 'server/conf'로 끝나는 기존 디렉토리여야 함
#    예: /Jazz/IBM/RRC_3.x/jazz/server/conf
#
OLD_APPLICATION_HOME=

# 매개변수: -applicationContextRoot
# 사용법: -applicationContextRoot <루트>
# 설명:
# 	애플리케이션 컨텍스트 루트입니다.
# 기본값:
# 	<없음>
# 제한 조건:
#  - <루트>는 올바른 하나의 디렉토리 이름이어야 함(즉, 앞에 슬래시가 없음)
#
APPLICATION_CONTEXT_ROOT=

# 매개변수: -oldApplicationVersion
# 사용법: -oldApplicationVersion <버전>
# 설명:
# 	업그레이드 중인 버전입니다. 기본적으로 이는 이전 애플리케이션에 대하여
#   repotools -version을 실행하여 판별됩니다.
# 기본값:
# 	<없음>
# 제한조건:
#  - 완전한 버전 문자열이어야 함
#    예: 5.0.0 또는 5.0.1
#
OLD_APPLICATION_VERSION=

# 매개변수: -updateTomcatFiles
# 사용법: -updateTomcatFiles <yes | no>
# 설명:
# 	Tomcat 구성 파일을 업데이트할지 여부입니다.
# 기본값:
# 	yes
# 제한조건:
#  - 올바른 값은 'yes' 및 'no' 만 해당됩니다.
#
UPDATE_TOMCAT_FILES=yes

# 매개변수: -oldApplicationTomcatHome
# 사용법: -oldApplicationTomcatHome <디렉토리 경로>
# 설명:
# 	이전 설치에서 애플리케이션 Tomcat 루트 디렉토리에 대한 전체 경로입니다.
# 기본값:
# 	<없음>
# 제한조건:
#  - RM 업그레이드에 대해서만 허용됨
#  - 기존 디렉토리여야 함
#
OLD_TOMCAT_HOME=

# 매개변수: -oldJTSTomcatHome
# 사용법: -oldJTSTomcatHome <디렉토리 경로>
# 설명:
# 	이전 설치에서 JTS Tomcat 루트 디렉토리에 대한 전체 경로입니다.
# 기본값:
# 	<없음>
# 제한조건:
#  - RM 업그레이드에 대해서만 허용됨
#  - 기존 디렉토리여야 함
#
OLD_JTS_TOMCAT_HOME=

# 매개변수: -newApplicationHome
# 사용법: -newApplicationHome <디렉토리 경로>
# 설명:
# 	새 설치에서 애플리케이션 홈 디렉토리에 대한 경로입니다.
# 기본값:
# 	conf
# 제한조건:
#  - RTC, QM 및 RM 업그레이드에 대해서만 허용됨
#  - 허용되는 경우 이는 필수 매개변수임
#  - <디렉토리 경로>는 'server/conf'로 끝나는 기존 디렉토리여야 함
#    예: /Jazz/IBM/RRC_4.0/JazzTeamServer/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# 매개변수: -newJTSHome
# 사용법: -newJTSHome <디렉토리 경로>
# 설명:
# 	새 설치에서 사용할 JTS에서 JTS 홈 디렉토리에 대한 전체 경로입니다.
# 기본값:
# 	새 애플리케이션 홈 디렉토리
# 제한조건:
#  - <디렉토리 경로>는 'server/conf'로 끝나는 기존 디렉토리여야 함
#
NEW_JTS_HOME=

# 매개변수: -newJTSContextRoot
# 사용법: -newJTSContextRoot <root>
# 설명:
# 	새 JTS 서버의 컨텍스트 루트입니다.
# 기본값:
# 	jts
# 제한조건:
#  - <root>는 올바른 디렉토리 단일 이름이어야 합니다. (즉, 앞에 슬래시가 없음)
#
JTS_CONTEXT_ROOT=jts

# 매개변수: -newApplicationTomcatHome
# 사용법: -newApplicationTomcatHome <디렉토리 경로>
# 설명:
# 	새 설치에서 애플리케이션 Tomcat 루트 디렉토리에 대한 경로입니다.
# 기본값:
# 	<없음>
#
NEW_TOMCAT_HOME=

# 매개변수: -newJTSTomcatHome
# 사용법: -newJTSTomcatHome <디렉토리 경로>
# 설명:
# 	새 설치에서 사용할 JTS에서 JTS Tomcat 루트 디렉토리에 대한 경로입니다.
# 기본값:
# 	<없음>
#
NEW_JTS_TOMCAT_HOME=

# 매개변수: -noPrompt
# 사용법: -noPrompt
# 설명:
# 	repotools 명령을 실행하는 동안에는 확인 프롬프트를 표시하지 않음(즉, 항상 noPrompt 사용)
# 기본값:
# 	<없음>
# 제한조건:
#  - 비어 있거나 'noPrompt'만 올바른 값임
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# 매개변수: -overwrite
# 사용법: -overwrite
# 설명:
# 	repotools 명령을 실행하는 동안에 겹쳐쓰기를 강제 실행함(즉, 항상 overwrite=yes 사용)
# 기본값:
# 	<없음>
# 제한조건:
#  - 비어 있거나 'overwrite=yes'만 올바른 값임
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# 매개변수: -noVerify
# 사용법: -noVerify
# 설명:
# 	repotools 명령을 실행하는 동안에는 검증을 수행하지 않음(즉, 항상 noVerify 사용)
# 기본값:
# 	<없음>
# 제한조건:
#  - 비어 있거나 'noVerify'만 올바른 값임
#
# NO_VERIFY=noVerify
NO_VERIFY=

# 매개변수: -noStepPrompt
# 사용법: -noStepPrompt
# 설명:
# 	각각의 업그레이드 단계 전에 프롬프트를 표시하지 않음
# 기본값:
# 	false
# 제한조건:
#  - 'true' 또는 'false'만 올바른 값임
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false

# 매개변수: -db.jdbc.location
# 사용법: -db.jdbc.location <JDBC_URL>
# 설명:
# 	RM 데이터베이스에 대한 JDBC 위치입니다(4.x에서 5.x로 이동할 때만 필요함).
#
#		예제:
#			DB2 		//localhost:50000/RM_DB:user=db2admin;password={password};
#			DB2i 		//hostname;hold statements=true;metadata source=1;user=rmDBuser;password={password};
#			ORACLE		thin:rmDBuser/{password}@//oracleserver.example.com:1521/RM_DB
#			SQLSERVER	//localhost:1433;databaseName=RM_DB;user=rmDBuser;password={password};
#			DERBY		conf/rm/derby/repositoryDB
#
#		참고:
#			*-nix 시스템에서는 많은 문자(예: |  &  ;  <  >  (  )  $  `  \  "  '  <간격>  <탭>  <줄 바꾸기>)의 경우에
#			백슬래시로 이스케이프해야 합니다.
#		
#			DB2 		//localhost:50000/RM_DB:user=db2admin\;password={password}\;
#			DB2i 		//hostname;hold\ statements=true\;metadata\ source=1\;user=rmDBuser\;password={password}\;
#			ORACLE		thin:rmDBuser/{password}@//oracleserver.example.com:1521/RM_DB
#			SQLSERVER	//localhost:1433\;databaseName=RM_DB\;user=rmDBuser\;password={password}\;
#			DERBY		conf/rm/derby/repositoryDB	
# 기본값:
# 	<없음>
# 제한조건:
#  - 4.x에서 RM 업그레이드에 대해서만 허용됨
#
DB_JDBC_LOCATION_VALUE=

# 매개변수: -db.jdbc.password
# 사용법: -db.jdbc.password <JDBC_PASSWORD>
# 설명:
# 	"{password}"가 JDBC url에 표시될 경우에 대체되는 비밀번호(일반 텍스트 또는 암호화된 텍스트)입니다.
# 기본값:
# 	<없음>
# 제한조건:
#  - RM 데이터베이스에 대한 JDBC URL에 {password}가 포함된 경우 지정되어야 함
#
DB_JDBC_PASSWORD_VALUE=


# 매개변수: -db.db2i.schema.name
# 사용법: -db.db2i.schema.name <SCHEMA_NAME>
# 설명:
# 	DB2i DB 스키마 이름.
# 기본값:
# 	<없음>
# 제한조건:
#  - DB2i 데이터베이스 유형을 사용하여 지정되어야 합니다.
#
DB_DB2I_SCHEMA_NAME_VALUE=

# 매개변수: -db.db2.dsn.dbname
# 사용법: -db.db2.dsn.dbname <DSN_DBNAME>
# 설명:
# 	DB2Z DSN DB 이름.
# 기본값:
# 	<없음>
# 제한조건:
#  - DB2z 데이터베이스 유형을 사용하여 지정되어야 합니다.
#
DB_DB2_DSN_DBNAME_VALUE=

# 매개변수: -db.schemaPrefix
# 사용법: -db.schemaPrefix <SCHEMA_PREFIX>
# 설명:
# 	DB 스키마 접두부.
# 기본값:
# 	<없음>
# 제한조건:
#  - DB2z 데이터베이스 유형을 사용하여 지정되어야 합니다.
#
DB_SCHEMA_PREFIX_VALUE=

# 매개변수: -oldJTSHome
# 사용법: -oldJTSHome <디렉토리 경로>
# 설명:
# 	이전 설치에서 JTS 홈 디렉토리의 전체 경로입니다.
# 기본값:
# 	<없음>
# 제한조건:
#  - <디렉토리 경로>는 'server/conf'로 끝나는 기존 디렉토리여야 함
#  - RM 및 JTS 업그레이드에 대해서만 유효함
#
OLD_JTS_HOME=

# 매개변수: -lpaContextRoot
# 사용법: -lpaContextRoot <루트>
# 설명:
# 	LPA 컨텍스트 루트임
# 기본값:
# 	admin
# 제한조건:
#  - <루트>는 올바른 하나의 디렉토리 이름이어야 함(예: 선행 슬래시 없음)
#
LPA_CONTEXT_ROOT=admin
